Welcome to tomita!
======

.. image:: https://img.shields.io/pypi/v/tomita.svg
        :target: https://pypi.python.org/pypi/tomita

.. image:: https://img.shields.io/travis/python-g4brielvs/tomita.svg
        :target: https://travis-ci.com/g4brielvs/python-tomita

.. image:: https://pyup.io/repos/github/g4brielvs/python-tomita/shield.svg
     :target: https://pyup.io/repos/github/g4brielvs/python-tomita
     :alt: Updates

.. image:: https://readthedocs.org/projects/tomita/badge/?version=latest
        :target: https://tomita.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/Tomita.svg
        :target: https://pypi.python.org/pypi/tomita/
        :alt: License

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
